@@ -1,7 +1,8 @@
-use strictures 1;
+use strict;
+use warnings;
 package App::skryf;
 
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.008';
 
 1;
 
@@ -9,7 +10,7 @@ __END__
 
 =head1 NAME
 
-App-skryf - perl blogger
+App-skryf - i kno rite. another perl blogging engine.
 
 =head1 DESCRIPTION
 
@@ -20,10 +21,9 @@ a more streamlined deployable approach.
 
 I like L<http://perlbrew.pl>, but, whatever you're comfortable with. I won't judge.
 
-=head1 INSTALLATION (SOURCE)
+=head1 INSTALLATION (BLEEDING EDGE)
 
-    $ git clone git://github.com/battlemidget/App-skryf.git
-    $ cpanm --installdeps .
+    $ cpanm git://github.com/battlemidget/App-skryf.git
 
 =head1 SETUP
 
@@ -40,17 +40,26 @@ and I<template_directory>.
     ##   %bindir%   (path to executable's dir)
     ##   %homedir%  (current $HOME)
     post_directory     => '%homedir%/blog/posts',
+    static_directory   => '%homedir%/blog/static',
     template_directory => '%homedir%/blog/templates',
     media_directory    => '%homedir%/blog/public',
 
 You'll want to make sure that files exist that reflect the template configuration options.
 
-    post_template  => 'post',
-    index_template => 'index',
-    about_template => 'about',
+    post_template   => 'post',
+    index_template  => 'index',
+    static_template => 'static',
 
 So B<~/blog/templates/{post.html.ep,index.html.ep,about.html.ep}> and B<~/blog/public/style.css>
 
+=head1 NEW POST
+
+    $ skryf newpost a-new-blog-post
+
+=head1 NEW PAGE
+
+    $ skryf newpage an-about-page
+
 =head1 DEPLOY
 
     $ export BLOGUSER=username
@@ -63,7 +72,7 @@ So B<~/blog/templates/{post.html.ep,index.html.ep,about.html.ep}> and B<~/blog/p
 
 =head1 RUN (Development)
 
-    $ morbo `which skryf`
+    $ skryf daemon
 
 =head1 RUN (Production)
 
@@ -81,7 +90,11 @@ I use Ubic to manage the process
 
 =head1 AUTHOR
 
-Adam Stokes <adamjs@cpan.org>
+Adam Stokes E<lt>adamjs@cpan.orgE<gt>
+
+=head1 COPYRIGHT
+
+Copyright 2013- Adam Stokes
 
 =head1 DISCLAIMER
 
